@@ -50,7 +50,7 @@ def is_admin():
     def decorator(func):
         @functools.wraps(func)
         async def wrapper(event):
-            sed = await adminbot.get_permissions(event.chat_id, event.sender_id)
+            sed = await utilsbot.get_permissions(event.chat_id, event.sender_id)
             user = event.sender_id
             if sed.is_admin:
                 await func(event)
@@ -66,8 +66,8 @@ def is_bot_admin():
     def decorator(func):
         @functools.wraps(func)
         async def wrapper(event):
-            pep = await adminbot.get_me()
-            sed = await adminbot.get_permissions(event.chat_id, pep)
+            pep = await utilsbot.get_me()
+            sed = await utilsbot.get_permissions(event.chat_id, pep)
             if sed.is_admin:
                 await func(event)
             else:
